==> safe_network-0.19.0.crate: safe_network-0.19.0/src/node/README.md <==
# sn_node

|Crate|Documentation|Safe Rust|
|:---:|:-----------:|:-------:|
|[![](http://meritbadge.herokuapp.com/sn_node)](https://crates.io/crates/sn_node)|[![Documentation](https://docs.rs/sn_node/badge.svg)](https://docs.rs/sn_node)|[![unsafe forbidden](https://img.shields.io/badge/unsafe-forbidden-success.svg)](https://github.com/rust-secure-code/safety-dance/)

| [MaidSafe website](https://maidsafe.net) | [Safe Dev Forum](https://forum.safedev.org) | [Safe Network Forum](https://safenetforum.org) |
|:----------------------------------------:|:-------------------------------------------:|:----------------------------------------------:|

## Overview

An autonomous network capable of data storage/publishing/sharing as well as computation, value transfer (crypto currency support) and more. See the documentation for a more detailed description of the operations involved in data storage.

## Crate Dependencies
Crate dependencies graph:

![sn_node MaidSafe dependencies](https://github.com/maidsafe/sn_node/blob/png_generator/sn_node_maidsafe_dependencies.png)


### Legend
Dependencies are coloured depending on their kind:
* **Black:** regular dependency
* **Purple:** build dependency
* **Blue:** dev dependency
* **Red:** optional dependency

A dependency can be of more than one kind. In such cases, it is coloured with the following priority:
`Regular -> Build -> Dev -> Optional`

<details>
<summary> View all sn_node dependencies</summary>
<p>

![sn_node all dependencies](https://github.com/maidsafe/sn_node/blob/png_generator/sn_node_all_dependencies.png)

</p>
</details>

Click [here](https://maidsafe.github.io/interdependency-svg-generator/) for an overview of the interdependencies of all the main MaidSafe components.

## License

This Safe Network library is licensed under the General Public License (GPL), version 3 ([LICENSE](LICENSE) https://www.gnu.org/licenses/gpl-3.0.en.html).

### Linking exception

sn_node is licensed under GPLv3 with linking exception. This means you can link to and use the library from any program, proprietary or open source; paid or gratis. However, if you modify sn_node, you must distribute the source to your modified version under the terms of the GPLv3.

See [the LICENSE file](LICENSE) for more details.

## Contributing

Want to contribute? Great :tada:

There are many ways to give back to the project, whether it be writing new code, fixing bugs, or just reporting errors. All forms of contributions are encouraged!

For instructions on how to contribute, see our [Guide to contributing](https://github.com/maidsafe/QA/blob/master/CONTRIBUTING.md).

==> safe_network-0.35.16.crate: safe_network-0.35.16/src/node/README.md <==
# sn_node

|Crate|Documentation|Safe Rust|
|:---:|:-----------:|:-------:|
|[![](https://img.shields.io/crates/v/sn_node)](https://crates.io/crates/sn_node)|[![Documentation](https://docs.rs/sn_node/badge.svg)](https://docs.rs/sn_node)|[![unsafe forbidden](https://img.shields.io/badge/unsafe-forbidden-success.svg)](https://github.com/rust-secure-code/safety-dance/)

| [MaidSafe website](https://maidsafe.net) | [Safe Dev Forum](https://forum.safedev.org) | [Safe Network Forum](https://safenetforum.org) |
|:----------------------------------------:|:-------------------------------------------:|:----------------------------------------------:|

## Overview

An autonomous network capable of data storage/publishing/sharing as well as computation, value transfer (crypto currency support) and more. See the documentation for a more detailed description of the operations involved in data storage.

## Crate Dependencies
Crate dependencies graph:

![sn_node MaidSafe dependencies](https://github.com/maidsafe/sn_node/blob/png_generator/sn_node_maidsafe_dependencies.png)


### Legend
Dependencies are coloured depending on their kind:
* **Black:** regular dependency
* **Purple:** build dependency
* **Blue:** dev dependency
* **Red:** optional dependency

A dependency can be of more than one kind. In such cases, it is coloured with the following priority:
`Regular -> Build -> Dev -> Optional`

<details>
<summary> View all sn_node dependencies</summary>
<p>

![sn_node all dependencies](https://github.com/maidsafe/sn_node/blob/png_generator/sn_node_all_dependencies.png)

</p>
</details>

Click [here](https://maidsafe.github.io/interdependency-svg-generator/) for an overview of the interdependencies of all the main MaidSafe components.

## License

This Safe Network library is licensed under the General Public License (GPL), version 3 ([LICENSE](LICENSE) https://www.gnu.org/licenses/gpl-3.0.en.html).

### Linking exception

sn_node is licensed under GPLv3 with linking exception. This means you can link to and use the library from any program, proprietary or open source; paid or gratis. However, if you modify sn_node, you must distribute the source to your modified version under the terms of the GPLv3.

See [the LICENSE file](LICENSE) for more details.

## Contributing

Want to contribute? Great :tada:

There are many ways to give back to the project, whether it be writing new code, fixing bugs, or just reporting errors. All forms of contributions are encouraged!

For instructions on how to contribute, see our [Guide to contributing](https://github.com/maidsafe/QA/blob/master/CONTRIBUTING.md).
